@@ -97,7 +97,7 @@ namespace apvlv
 
     void setactive (bool act);
 
-    returnType process (int times, guint keyval);
+    returnType process (int hastimes, int times, guint keyval);
 
   private:
 
@@ -117,12 +117,12 @@ namespace apvlv
 
     bool search (const char *str, bool reverse = false);
 
-    static void apvlv_dir_on_changed (GtkTreeSelection *, ApvlvDir *);
-
     bool walk_file_index (GtkTreeIter * titr, ApvlvFileIndexIter iter);
 
     bool walk_dir_path_index (GtkTreeIter * titr, const char *path);
 
+    static void apvlv_dir_on_changed (GtkTreeSelection *, ApvlvDir *);
+
     static gboolean apvlv_dir_first_select_cb (ApvlvDir *);
 
     gint mFirstSelTimer;
