@@ -50,6 +50,10 @@ namespace apvlv
   extern string iconpdf;
   extern string sessionfile;
 
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+
 #ifdef WIN32
 #define PATH_SEP_C  '\\'
 #define PATH_SEP_S  "\\"
@@ -102,6 +106,8 @@ namespace apvlv
 
 #endif
 
+  gboolean walkdir (const char *, gboolean (*)(const char *, void *), void *);
+
   // log system
 #if defined DEBUG || defined _DEBUG
 #define debug(...)      logv ("DEBUG", __FILE__, __LINE__, __func__, __VA_ARGS__)
