@@ -395,6 +395,7 @@ namespace apvlv
     if (mTabList.size () > 1)
       {
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (mTabContainer), TRUE);
+	gtk_widget_set_size_request (mTabContainer, mWidth - 12, 12);
       }
 
     return mCurrTabPos + 1;
@@ -801,7 +802,7 @@ namespace apvlv
     return MATCH;
   }
 
-  returnType ApvlvView::process (int ct, guint key)
+  returnType ApvlvView::process (int has, int ct, guint key)
   {
     if (mProCmd != 0)
       {
@@ -824,7 +825,7 @@ namespace apvlv
 	mProCmd = 'g';
 	return NEED_MORE;
       default:
-	return crtadoc ()->process (ct, key);
+	return crtadoc ()->process (has, ct, key);
 	break;
       }
 
@@ -878,7 +879,7 @@ namespace apvlv
 	string cmd, subcmd, argu;
 	ss >> cmd >> subcmd >> argu;
 
-	if (subcmd[subcmd.length () - 1] == '\\')
+	if (subcmd.length () > 0 && subcmd[subcmd.length () - 1] == '\\')
 	  {
 	    subcmd.replace (subcmd.length () - 1, 1, 1, ' ');
 	    subcmd += argu;
@@ -1069,7 +1070,7 @@ namespace apvlv
       {
 	view->mWidth = w;
 	view->mHeight = h;
-	view->mRootWindow->setsize (w, view->adjheight ());
+	view->mRootWindow->setsize (w, view->adjheight () - 10);
       }
   }
 
@@ -1215,18 +1216,19 @@ namespace apvlv
   {
     int adj = 0;
     if (gtk_notebook_get_show_tabs (GTK_NOTEBOOK (mTabContainer)))
-      adj += APVLV_TABS_HEIGHT;
+      {
+	adj += APVLV_TABS_HEIGHT;
+      }
     if (mCmdType != CMD_NONE)
-      adj += APVLV_CMD_BAR_HEIGHT;
-
+      {
+	adj += APVLV_CMD_BAR_HEIGHT;
+      }
     if (strchr (gParams->values ("guioptions"), 'm') != NULL)
       {
-	return mHeight - APVLV_MENU_HEIGHT - adj;
-      }
-    else
-      {
-	return mHeight - adj;
+	adj += APVLV_MENU_HEIGHT;
       }
+
+    return mHeight - adj;
   }
 
   void ApvlvView::switchtab (int tabPos)
